'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteServiceProvider = void 0;
const goodies_1 = require("@supercharge/goodies");
const support_1 = require("@supercharge/support");
class RouteServiceProvider extends support_1.ServiceProvider {
    constructor() {
        super(...arguments);
        /**
         * Stores the callback functions that load route files.
         */
        this.loadRoutesCallbacks = [];
    }
    /**
     * Register application services to the container.
     */
    register() {
        this.booted(() => {
            this.runRouteLoadingCallbacks();
        });
    }
    /**
     * Run the registered route-loading callbacks.
     */
    runRouteLoadingCallbacks() {
        this.loadRoutesCallbacks.forEach(callback => {
            callback();
        });
    }
    /**
     * Load the routes file from the given `path`.
     *
     * @param callback
     *
     * @returns {this}
     */
    loadRoutesFrom(path) {
        return this.loadRoutesUsing(() => {
            this.clearRequireCacheFor(path);
            require(path);
        });
    }
    /**
     * Delete the require cache entry for the given `path` if it exists.
     *
     * @see https://nodejs.org/api/modules.html#modules_caching
     *
     * @param path
     *
     * @returns {this}
     */
    clearRequireCacheFor(path) {
        if (require.cache[path]) {
            // eslint-disable-next-line @typescript-eslint/no-dynamic-delete
            delete require.cache[path];
        }
        return this;
    }
    /**
     * Register a callback that will be used to load the application’s routes.
     *
     * @param callback
     *
     * @returns {this}
     */
    loadRoutesUsing(callback) {
        return (0, goodies_1.tap)(this, () => {
            this.loadRoutesCallbacks.push(callback);
        });
    }
}
exports.RouteServiceProvider = RouteServiceProvider;
